@@ -4,7 +4,9 @@ SIGNALS = [
     signal.SIGTERM,
     signal.SIGINT,
 ]
-
+REQUEST_ID_KEY = '_supergood_request_id'
+GZIP_START_BYTES = b'\x1f\x8b'
+DEFAULT_SUPERGOOD_BYTE_LIMIT = 500000
 DEFAULT_SUPERGOOD_CONFIG_URL = 'https://dashboard.supergood.ai/api/config/'
 DEFAULT_SUPERGOOD_BASE_URL = 'https://dashboard.supergood.ai/'
 DEFAULT_SUPERGOOD_CONFIG = {
